@@ -87,17 +87,17 @@ M.util.CollapsibleRegion = function(Y, id, userpref, strtooltip) {
 
     // Get the caption for the collapsible region
     var caption = this.div.one('#'+id + '_caption');
-    caption.setAttribute('title', strtooltip);
 
     // Create a link
     var a = Y.Node.create('<a href="#"></a>');
-    // Create a local scoped lamba function to move nodes to a new link
-    var movenode = function(node){
-        node.remove();
-        a.append(node);
-    };
-    // Apply the lamba function on each of the captions child nodes
-    caption.get('children').each(movenode, this);
+    a.setAttribute('title', strtooltip);
+
+    // Get all the nodes from caption, remove them and append them to <a>
+    while (caption.hasChildNodes()) {
+        child = caption.get('firstChild');
+        child.remove();
+        a.append(child);
+    }
     caption.append(a);
 
     // Get the height of the div at this point before we shrink it if required
@@ -715,7 +715,13 @@ M.util.get_string = function(identifier, component, a) {
         // creating new instance if YUI is not optimal but it seems to be better way then
         // require the instance via the function API - note that it is used in rare cases
         // for debugging only anyway
-        var Y = new YUI({ debug : true });
+        // To ensure we don't kill browser performance if hundreds of get_string requests
+        // are made we cache the instance we generate within the M.util namespace.
+        // We don't publicly define the variable so that it doesn't get abused.
+        if (typeof M.util.get_string_yui_instance === 'undefined') {
+            M.util.get_string_yui_instance = new YUI({ debug : true });
+        }
+        var Y = M.util.get_string_yui_instance;
     }
 
     if (!M.str.hasOwnProperty(component) || !M.str[component].hasOwnProperty(identifier)) {
@@ -1103,17 +1109,58 @@ function openpopup(event, args) {
         }
     }
 
+    // Make sure the name argument is set and valid.
+    var nameregex = /[^a-z0-9_]/i;
+    if (typeof args.name !== 'string') {
+        args.name = '_blank';
+    } else if (args.name.match(nameregex)) {
+        // Cleans window name because IE does not support funky ones.
+        args.name = args.name.replace(nameregex, '_');
+        if (M.cfg.developerdebug) {
+            alert('DEVELOPER NOTICE: Invalid \'name\' passed to openpopup()');
+        }
+    }
+
     var fullurl = args.url;
     if (!args.url.match(/https?:\/\//)) {
         fullurl = M.cfg.wwwroot + args.url;
     }
+    if (args.fullscreen) {
+        args.options = args.options.
+                replace(/top=\d+/, 'top=0').
+                replace(/left=\d+/, 'left=0').
+                replace(/width=\d+/, 'width=' + screen.availWidth).
+                replace(/height=\d+/, 'height=' + screen.availHeight);
+    }
     var windowobj = window.open(fullurl,args.name,args.options);
     if (!windowobj) {
         return true;
     }
+
     if (args.fullscreen) {
-        windowobj.moveTo(0,0);
-        windowobj.resizeTo(screen.availWidth,screen.availHeight);
+        // In some browser / OS combinations (E.g. Chrome on Windows), the
+        // window initially opens slighly too big. The width and heigh options
+        // seem to control the area inside the browser window, so what with
+        // scroll-bars, etc. the actual window is bigger than the screen.
+        // Therefore, we need to fix things up after the window is open.
+        var hackcount = 100;
+        var get_size_exactly_right = function() {
+            windowobj.moveTo(0, 0);
+            windowobj.resizeTo(screen.availWidth, screen.availHeight);
+
+            // Unfortunately, it seems that in Chrome on Ubuntu, if you call
+            // something like windowobj.resizeTo(1280, 1024) too soon (up to
+            // about 50ms) after the window is open, then it actually behaves
+            // as if you called windowobj.resizeTo(0, 0). Therefore, we need to
+            // check that the resize actually worked, and if not, repeatedly try
+            // again after a short delay until it works (but with a limit of
+            // hackcount repeats.
+            if (hackcount > 0 && (windowobj.innerHeight < 10 || windowobj.innerWidth < 10)) {
+                hackcount -= 1;
+                setTimeout(get_size_exactly_right, 10);
+            }
+        }
+        setTimeout(get_size_exactly_right, 0);
     }
     windowobj.focus();
 
@@ -1260,16 +1307,17 @@ M.util.help_icon = {
         event.preventDefault();
         if (M.util.help_icon.instance === null) {
             var Y = M.util.help_icon.Y;
-            Y.use('overlay', 'io-base', 'event-mouseenter', 'node', 'event-key', function(Y) {
+            Y.use('overlay', 'io-base', 'event-mouseenter', 'node', 'event-key', 'escape', function(Y) {
                 var help_content_overlay = {
                     helplink : null,
                     overlay : null,
                     init : function() {
 
-                        var closebtn = Y.Node.create('<a id="closehelpbox" href="#"><img  src="'+M.util.image_url('t/delete', 'moodle')+'" /></a>');
+                        var strclose = Y.Escape.html(M.str.form.close);
+                        var footerbtn = Y.Node.create('<button class="closebtn">'+strclose+'</button>');
                         // Create an overlay from markup
                         this.overlay = new Y.Overlay({
-                            headerContent: closebtn,
+                            footerContent: footerbtn,
                             bodyContent: '',
                             id: 'helppopupbox',
                             width:'400px',
@@ -1278,7 +1326,7 @@ M.util.help_icon = {
                         });
                         this.overlay.render(Y.one(document.body));
 
-                        closebtn.on('click', this.overlay.hide, this.overlay);
+                        footerbtn.on('click', this.overlay.hide, this.overlay);
 
                         var boundingBox = this.overlay.get("boundingBox");
 
@@ -1294,9 +1342,6 @@ M.util.help_icon = {
                                 this.overlay.hide();
                             }
                         }, this);
-
-                        Y.on("key", this.close, closebtn , "down:13", this);
-                        closebtn.on('click', this.close, this);
                     },
 
                     close : function(e) {
@@ -1306,9 +1351,16 @@ M.util.help_icon = {
                     },
 
                     display : function(event, args) {
+                        if (Y.one('html').get('dir') == 'rtl') {
+                            var overlayPosition = [Y.WidgetPositionAlign.TR, Y.WidgetPositionAlign.LC];
+                        } else {
+                            var overlayPosition = [Y.WidgetPositionAlign.TL, Y.WidgetPositionAlign.RC];
+                        }
+
                         this.helplink = args.node;
+
                         this.overlay.set('bodyContent', Y.Node.create('<img src="'+M.cfg.loadingicon+'" class="spinner" />'));
-                        this.overlay.set("align", {node:args.node, points:[Y.WidgetPositionAlign.TL, Y.WidgetPositionAlign.RC]});
+                        this.overlay.set("align", {node:args.node, points: overlayPosition});
 
                         var fullurl = args.url;
                         if (!args.url.match(/https?:\/\//)) {
@@ -1336,11 +1388,10 @@ M.util.help_icon = {
 
                         Y.io(ajaxurl, cfg);
                         this.overlay.show();
-
-                        Y.one('#closehelpbox').focus();
                     },
 
                     display_callback : function(content) {
+                        content = '<div role="alert">' + content + '</div>';
                         this.overlay.set('bodyContent', content);
                     },
 
@@ -1702,14 +1753,27 @@ M.util.load_flowplayer = function() {
 
             var rule;
             for (var j=0; j < document.styleSheets.length; j++) {
-                if (typeof (document.styleSheets[j].rules) != 'undefined') {
-                    var allrules = document.styleSheets[j].rules;
-                } else if (typeof (document.styleSheets[j].cssRules) != 'undefined') {
-                    var allrules = document.styleSheets[j].cssRules;
-                } else {
-                    // why??
+
+                // To avoid javascript security violation accessing cross domain stylesheets
+                var allrules = false;
+                try {
+                    if (typeof (document.styleSheets[j].rules) != 'undefined') {
+                        allrules = document.styleSheets[j].rules;
+                    } else if (typeof (document.styleSheets[j].cssRules) != 'undefined') {
+                        allrules = document.styleSheets[j].cssRules;
+                    } else {
+                        // why??
+                        continue;
+                    }
+                } catch (e) {
                     continue;
                 }
+
+                // On cross domain style sheets Chrome V8 allows access to rules but returns null
+                if (!allrules) {
+                    continue;
+                }
+
                 for(var i=0; i<allrules.length; i++) {
                     rule = '';
                     if (/^\.mp3flowplayer_.*Color$/.test(allrules[i].selectorText)) {
