@@ -1,6 +1,34 @@
 #!/usr/bin/php -q
 <?php
 
+// This file is part of Moodle - http://moodle.org/
+//
+// Moodle is free software: you can redistribute it and/or modify
+// it under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Moodle is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.
+
+/**
+ * Chat daemon
+ *
+ * @package    mod_chat
+ * @copyright  1999 onwards Martin Dougiamas  {@link http://moodle.com}
+ * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
+ */
+
+define('CLI_SCRIPT', true);
+
+require(dirname(dirname(dirname(__FILE__))).'/config.php');
+require_once($CFG->dirroot . '/mod/chat/lib.php');
+
 // Browser quirks
 define('QUIRK_CHUNK_UPDATE', 0x0001);
 
@@ -17,7 +45,7 @@ define('CHAT_SIDEKICK_MESSAGE',     0x22);
 define('CHAT_SIDEKICK_BEEP',        0x23);
 
 $phpversion = phpversion();
-echo 'Moodle chat daemon v1.0 on PHP '.$phpversion." (\$Id: chatd.php,v 1.32.4.3 2008/10/08 06:41:55 dongsheng Exp $)\n\n";
+echo 'Moodle chat daemon v1.0 on PHP '.$phpversion."\n\n";
 
 /// Set up all the variables we need   /////////////////////////////////////
 
@@ -27,30 +55,15 @@ $_SERVER['PHP_SELF']        = 'dummy';
 $_SERVER['SERVER_NAME']     = 'dummy';
 $_SERVER['HTTP_USER_AGENT'] = 'dummy';
 
-$nomoodlecookie = true;
-
-include('../../config.php');
-include('lib.php');
-
 $_SERVER['SERVER_NAME'] = $CFG->chat_serverhost;
 $_SERVER['PHP_SELF']    = "http://$CFG->chat_serverhost:$CFG->chat_serverport/mod/chat/chatd.php";
 
 $safemode = ini_get('safe_mode');
-
-if($phpversion < '4.3') {
-    die("Error: The Moodle chat daemon requires at least PHP version 4.3 to run.\n       Since your version is $phpversion, you have to upgrade.\n\n");
-}
 if(!empty($safemode)) {
     die("Error: Cannot run with PHP safe_mode = On. Turn off safe_mode in php.ini.\n");
 }
 
-$passref = ini_get('allow_call_time_pass_reference');
-if(empty($passref)) {
-    die("Error: Cannot run with PHP allow_call_time_pass_reference = Off. Turn on allow_call_time_pass_reference in php.ini.\n");
-}
-
 @set_time_limit (0);
-set_magic_quotes_runtime(0);
 error_reporting(E_ALL);
 
 function chat_empty_connection() {
@@ -72,7 +85,7 @@ class ChatConnection {
 
     function ChatConnection($resource) {
         $this->handle = $resource;
-        @socket_getpeername($this->handle, &$this->ip, &$this->port);
+        @socket_getpeername($this->handle, $this->ip, $this->port);
     }
 }
 
@@ -204,6 +217,8 @@ class ChatDaemon {
     }
 
     function user_lazy_update($sessionid) {
+        global $DB;
+
         // TODO: this can and should be written as a single UPDATE query
         if(empty($this->sets_info[$sessionid])) {
             $this->trace('user_lazy_update() called for an invalid SID: '.$sessionid, E_USER_WARNING);
@@ -217,19 +232,17 @@ class ChatDaemon {
         if($now - $this->sets_info[$sessionid]['lastinfocommit'] > $this->_freq_update_records) {
             // commit to permanent storage
             $this->sets_info[$sessionid]['lastinfocommit'] = $now;
-            update_record('chat_users', $this->sets_info[$sessionid]['chatuser']);
+            $DB->update_record('chat_users', $this->sets_info[$sessionid]['chatuser']);
         }
         return true;
     }
 
     function get_user_window($sessionid) {
-
-        global $CFG;
+        global $CFG, $OUTPUT;
 
         static $str;
 
         $info = &$this->sets_info[$sessionid];
-        course_setup($info['course'], $info['user']);
 
         $timenow = time();
 
@@ -277,11 +290,17 @@ EOD;
             $userinfo = $this->sets_info[$usersessionid];
 
             $lastping = $timenow - $userinfo['chatuser']->lastmessageping;
-            $popuppar = '\'/user/view.php?id='.$userinfo['user']->id.'&amp;course='.$userinfo['courseid'].'\',\'user'.$userinfo['chatuser']->id.'\',\'\'';
+
             echo '<tr><td width="35">';
-            echo '<a target="_new" onclick="return openpopup('.$popuppar.');" href="'.$CFG->wwwroot.'/user/view.php?id='.$userinfo['chatuser']->id.'&amp;course='.$userinfo['courseid'].'">';
-            print_user_picture($userinfo['user']->id, 0, $userinfo['user']->picture, false, false, false);
-            echo "</a></td><td valign=\"center\">";
+
+            $link = '/user/view.php?id='.$userinfo['user']->id.'&course='.$userinfo['courseid'];
+            $anchortagcontents = $OUTPUT->user_picture($userinfo['user'], array('courseid'=>$userinfo['courseid']));
+
+            $action = new popup_action('click', $link, 'user'.$userinfo['chatuser']->id);
+            $anchortag = $OUTPUT->action_link($link, $anchortagcontents, $action);
+
+            echo $anchortag;
+            echo "</td><td valign=\"center\">";
             echo "<p><font size=\"1\">";
             echo fullname($userinfo['user'])."<br />";
             echo "<font color=\"#888888\">$str->idle: ".format_time($lastping, $str)."</font> ";
@@ -323,12 +342,12 @@ EOD;
     }
 
     function dispatch_sidekick($handle, $type, $sessionid, $customdata) {
-        global $CFG;
+        global $CFG, $DB;
 
         switch($type) {
             case CHAT_SIDEKICK_BEEP:
                 // Incoming beep
-                $msg = &New stdClass;
+                $msg = New stdClass;
                 $msg->chatid    = $this->sets_info[$sessionid]['chatid'];
                 $msg->userid    = $this->sets_info[$sessionid]['userid'];
                 $msg->groupid   = $this->sets_info[$sessionid]['groupid'];
@@ -337,7 +356,8 @@ EOD;
                 $msg->timestamp = time();
 
                 // Commit to DB
-                insert_record('chat_messages', $msg, false);
+                $DB->insert_record('chat_messages', $msg, false);
+                $DB->insert_record('chat_messages_current', $msg, false);
 
                 // OK, now push it out to all users
                 $this->message_broadcast($msg, $this->sets_info[$sessionid]['user']);
@@ -355,7 +375,7 @@ EOD;
                 $header .= "Connection: close\n";
                 $header .= "Date: ".date('r')."\n";
                 $header .= "Server: Moodle\n";
-                $header .= "Content-Type: text/html\n";
+                $header .= "Content-Type: text/html; charset=utf-8\n";
                 $header .= "Last-Modified: ".gmdate("D, d M Y H:i:s")." GMT\n";
                 $header .= "Cache-Control: no-cache, must-revalidate\n";
                 $header .= "Expires: Wed, 4 Oct 1978 09:32:45 GMT\n";
@@ -375,7 +395,7 @@ EOD;
                 $header .= "Connection: close\n";
                 $header .= "Date: ".date('r')."\n";
                 $header .= "Server: Moodle\n";
-                $header .= "Content-Type: text/html\n";
+                $header .= "Content-Type: text/html; charset=utf-8\n";
                 $header .= "Last-Modified: ".gmdate("D, d M Y H:i:s")." GMT\n";
                 $header .= "Cache-Control: no-cache, must-revalidate\n";
                 $header .= "Expires: Wed, 4 Oct 1978 09:32:45 GMT\n";
@@ -413,7 +433,7 @@ EOD;
                     $this->sets_info[$sessionid]['lastmessageindex'] = $messageindex;
                 }
 
-                $msg = &New stdClass;
+                $msg = New stdClass;
                 $msg->chatid    = $this->sets_info[$sessionid]['chatid'];
                 $msg->userid    = $this->sets_info[$sessionid]['userid'];
                 $msg->groupid   = $this->sets_info[$sessionid]['groupid'];
@@ -428,10 +448,11 @@ EOD;
 
                 // A slight hack to prevent malformed SQL inserts
                 $origmsg = $msg->message;
-                $msg->message = addslashes($msg->message);
+                $msg->message = $msg->message;
 
                 // Commit to DB
-                insert_record('chat_messages', $msg, false);
+                $DB->insert_record('chat_messages', $msg, false);
+                $DB->insert_record('chat_messages_current', $msg, false);
 
                 // Undo the hack
                 $msg->message = $origmsg;
@@ -452,7 +473,7 @@ EOD;
                 $header .= "Connection: close\n";
                 $header .= "Date: ".date('r')."\n";
                 $header .= "Server: Moodle\n";
-                $header .= "Content-Type: text/html\n";
+                $header .= "Content-Type: text/html; charset=utf-8\n";
                 $header .= "Last-Modified: ".gmdate("D, d M Y H:i:s")." GMT\n";
                 $header .= "Cache-Control: no-cache, must-revalidate\n";
                 $header .= "Expires: Wed, 4 Oct 1978 09:32:45 GMT\n";
@@ -470,31 +491,32 @@ EOD;
     }
 
     function promote_final($sessionid, $customdata) {
+        global $DB;
+
         if(isset($this->conn_sets[$sessionid])) {
             $this->trace('Set cannot be finalized: Session '.$sessionid.' is already active');
             return false;
         }
 
-        $chatuser = get_record('chat_users', 'sid', $sessionid);
+        $chatuser = $DB->get_record('chat_users', array('sid'=>$sessionid));
         if($chatuser === false) {
             $this->dismiss_half($sessionid);
             return false;
         }
-        $chat = get_record('chat', 'id', $chatuser->chatid);
+        $chat = $DB->get_record('chat', array('id'=>$chatuser->chatid));
         if($chat === false) {
             $this->dismiss_half($sessionid);
             return false;
         }
-        $user = get_record('user', 'id', $chatuser->userid);
+        $user = $DB->get_record('user', array('id'=>$chatuser->userid));
         if($user === false) {
             $this->dismiss_half($sessionid);
             return false;
         }
-        $course = get_record('course', 'id', $chat->course); {
-       if($course === false) {
+        $course = $DB->get_record('course', array('id'=>$chat->course));
+        if($course === false) {
             $this->dismiss_half($sessionid);
             return false;
-            }
         }
 
         global $CHAT_HTMLHEAD_JS, $CFG;
@@ -528,13 +550,23 @@ EOD;
 
         // $this->trace('QUIRKS value for this connection is '.$customdata['quirks']);
 
+        $header  = "HTTP/1.1 200 OK\n";
+        $header .= "Connection: close\n";
+        $header .= "Date: ".date('r')."\n";
+        $header .= "Server: Moodle\n";
+        $header .= "Content-Type: text/html; charset=utf-8\n";
+        $header .= "Last-Modified: ".gmdate("D, d M Y H:i:s")." GMT\n";
+        $header .= "Cache-Control: no-cache, must-revalidate\n";
+        $header .= "Expires: Wed, 4 Oct 1978 09:32:45 GMT\n";
+        $header .= "\n";
+
         $this->dismiss_half($sessionid, false);
-        $this->write_data($this->conn_sets[$sessionid][CHAT_CONNECTION_CHANNEL], $CHAT_HTMLHEAD_JS);
+        $this->write_data($this->conn_sets[$sessionid][CHAT_CONNECTION_CHANNEL], $header . $CHAT_HTMLHEAD_JS);
         $this->trace('Connection accepted: '.$this->conn_sets[$sessionid][CHAT_CONNECTION_CHANNEL].', SID: '.$sessionid.' UID: '.$chatuser->userid.' GID: '.$chatuser->groupid, E_USER_WARNING);
 
         // Finally, broadcast the "entered the chat" message
 
-        $msg = &New stdClass;
+        $msg = new stdClass;
         $msg->chatid = $chatuser->chatid;
         $msg->userid = $chatuser->userid;
         $msg->groupid = $chatuser->groupid;
@@ -542,7 +574,8 @@ EOD;
         $msg->message = 'enter';
         $msg->timestamp = time();
 
-        insert_record('chat_messages', $msg, false);
+        $DB->insert_record('chat_messages', $msg, false);
+        $DB->insert_record('chat_messages_current', $msg, false);
         $this->message_broadcast($msg, $this->sets_info[$sessionid]['user']);
 
         return true;
@@ -669,7 +702,7 @@ EOD;
             return false;
         }
 
-        $newconn = &New ChatConnection($handle);
+        $newconn = New ChatConnection($handle);
         $id = $this->new_ufo_id();
         $this->conn_ufo[$id] = $newconn;
 
@@ -696,6 +729,7 @@ EOD;
     }
 
     function message_broadcast($message, $sender) {
+
         if(empty($this->conn_sets)) {
             return true;
         }
@@ -712,7 +746,6 @@ EOD;
             {
 
                 // Simply give them the message
-                course_setup($info['course'], $info['user']);
                 $output = chat_format_message_manually($message, $info['courseid'], $sender, $info['user']);
                 $this->trace('Delivering message "'.$output->text.'" to '.$this->conn_sets[$sessionid][CHAT_CONNECTION_CHANNEL]);
 
@@ -735,10 +768,12 @@ EOD;
     }
 
     function disconnect_session($sessionid) {
+        global $DB;
+
         $info = $this->sets_info[$sessionid];
 
-        delete_records('chat_users', 'sid', $sessionid);
-        $msg = &New stdClass;
+        $DB->delete_records('chat_users', array('sid'=>$sessionid));
+        $msg = New stdClass;
         $msg->chatid = $info['chatid'];
         $msg->userid = $info['userid'];
         $msg->groupid = $info['groupid'];
@@ -747,7 +782,8 @@ EOD;
         $msg->timestamp = time();
 
         $this->trace('User has disconnected, destroying uid '.$info['userid'].' with SID '.$sessionid, E_USER_WARNING);
-        insert_record('chat_messages', $msg, false);
+        $DB->insert_record('chat_messages', $msg, false);
+        $DB->insert_record('chat_messages_current', $msg, false);
 
         // *************************** IMPORTANT
         //
@@ -960,7 +996,7 @@ else {
 $DAEMON->trace('Started Moodle chatd on port '.$CFG->chat_serverport.', listening socket '.$DAEMON->listen_socket, E_USER_WARNING);
 
 /// Clear the decks of old stuff
-delete_records('chat_users', 'version', 'sockets');
+$DB->delete_records('chat_users', array('version'=>'sockets'));
 
 while(true) {
     $active = array();
@@ -985,7 +1021,7 @@ while(true) {
                     continue;
                 }
 
-                if(!ereg('win=(chat|users|message|beep).*&chat_sid=([a-zA-Z0-9]*) HTTP', $data, $info)) {
+                if(!preg_match('/win=(chat|users|message|beep).*&chat_sid=([a-zA-Z0-9]*) HTTP/', $data, $info)) {
                     // Malformed data
                     $DAEMON->trace('UFO with '.$handle.': Request with malformed data; connection closed', E_USER_WARNING);
                     $DAEMON->dismiss_ufo($handle, true, 'Request with malformed data; connection closed');
@@ -1011,7 +1047,7 @@ while(true) {
                     break;
                     case 'beep':
                         $type = CHAT_SIDEKICK_BEEP;
-                        if(!ereg('beep=([^&]*)[& ]', $data, $info)) {
+                        if(!preg_match('/beep=([^&]*)[& ]/', $data, $info)) {
                             $DAEMON->trace('Beep sidekick did not contain a valid userid', E_USER_WARNING);
                             $DAEMON->dismiss_ufo($handle, true, 'Request with malformed data; connection closed');
                             continue;
@@ -1022,7 +1058,7 @@ while(true) {
                     break;
                     case 'message':
                         $type = CHAT_SIDEKICK_MESSAGE;
-                        if(!ereg('chat_message=([^&]*)[& ]chat_msgidnr=([^&]*)[& ]', $data, $info)) {
+                        if(!preg_match('/chat_message=([^&]*)[& ]chat_msgidnr=([^&]*)[& ]/', $data, $info)) {
                             $DAEMON->trace('Message sidekick did not contain a valid message', E_USER_WARNING);
                             $DAEMON->dismiss_ufo($handle, true, 'Request with malformed data; connection closed');
                             continue;
@@ -1061,4 +1097,4 @@ while(true) {
 @socket_shutdown($DAEMON->listen_socket, 0);
 die("\n\n-- terminated --\n");
 
-?>
+
