@@ -303,7 +303,7 @@ function qtype_multianswer_extract_question($text) {
     $question->defaultmark = 0; // Will be increased for each answer norm
 
     for ($positionkey = 1;
-            preg_match('/'.ANSWER_REGEX.'/', $question->questiontext['text'], $answerregs);
+            preg_match('/'.ANSWER_REGEX.'/s', $question->questiontext['text'], $answerregs);
             ++$positionkey) {
         $wrapped = new stdClass();
         $wrapped->generalfeedback['text'] = '';
@@ -389,7 +389,7 @@ function qtype_multianswer_extract_question($text) {
         $answerindex = 0;
 
         $remainingalts = $answerregs[ANSWER_REGEX_ALTERNATIVES];
-        while (preg_match('/~?'.ANSWER_ALTERNATIVE_REGEX.'/', $remainingalts, $altregs)) {
+        while (preg_match('/~?'.ANSWER_ALTERNATIVE_REGEX.'/s', $remainingalts, $altregs)) {
             if ('=' == $altregs[ANSWER_ALTERNATIVE_REGEX_FRACTION]) {
                 $wrapped->fraction["$answerindex"] = '1';
             } else if ($percentile = $altregs[ANSWER_ALTERNATIVE_REGEX_PERCENTILE_FRACTION]) {
@@ -411,7 +411,7 @@ function qtype_multianswer_extract_question($text) {
 
             }
             if (!empty($answerregs[ANSWER_REGEX_ANSWER_TYPE_NUMERICAL])
-                    && preg_match('~'.NUMERICAL_ALTERNATIVE_REGEX.'~',
+                    && preg_match('~'.NUMERICAL_ALTERNATIVE_REGEX.'~s',
                             $altregs[ANSWER_ALTERNATIVE_REGEX_ANSWER], $numregs)) {
                 $wrapped->answer[] = $numregs[NUMERICAL_CORRECT_ANSWER];
                 if (array_key_exists(NUMERICAL_ABS_ERROR_MARGIN, $numregs)) {
